
"""
Rust version of FZF (GO)
"""

from machineconfig.utils.utils import get_latest_release
import crocodile.toolbox as tb

def main(version=None):
    _ = version
    # repo_url = tb.P(r"https://github.com/lotabout/skim")
    # release = get_latest_release(repo_url.as_url_str(), suffix='x86_64-unknown-linux-musl', compression='tar.gz', linux=True, strip_v=True, download_n_extract=True)
    pass


if __name__ == '__main__':
    main()
